Re: [PATCH v2 0/5] Speed up remove_redundant()
- From
Junio C Hamano <gitster@pobox.com>
- Date
- Feb 18, 2021, 23:25 UTC
- Message-ID
- <xmqq8s7lc61j.fsf@gitster.g>
- In-Reply-To
- <7a1a8990-59e7-d538-d382-446fdc270810@gmail.com>
Derrick Stolee <stolee@gmail.com> writes:
Show 27 quoted lines
> On 2/1/2021 7:47 AM, Derrick Stolee via GitGitGadget wrote: >> My tests were on the Linux kernel repository, testing this command: >> >> git merge-base --independent $(git for-each-ref refs/tags --format="%(refname)") >> >> Before: 16.4s >> After Patch 1: 1.1s >> After Patch 2: 0.1s > > During my testing of v2, I discovered how remove_redundant() > is being used as part of 'git log --simplify-merges'. So, here > are some performance numbers for the Linux kernel repository > with a full commit-graph and changed-path Bloom filters running > > git log --oneline -n10 --simplify-merges -- kernel/ > > Benchmark #1: old > Time (mean ± σ): 5.770 s ± 0.030 s [User: 5.551 s, System: 0.219 s] > Range (min … max): 5.728 s … 5.827 s 10 runs > > Benchmark #2: new > Time (mean ± σ): 5.030 s ± 0.017 s [User: 4.805 s, System: 0.224 s] > Range (min … max): 4.999 s … 5.054 s 10 runs > > Summary > 'new' ran > 1.15 ± 0.01 times faster than 'old'
This topic seems to have been forgotten? Is the only thing missing is an updated 2/5 or is there anything more that is needed?